from dataclasses import dataclass, field

from mashumaro.mixins.orjson import DataClassORJSONMixin


@dataclass
class ConnectData(DataClassORJSONMixin):
    connect_type: int = 0
    ble_rssi: int = 0
    wifi_rssi: int = 0
    used_net: str = ""


@dataclass
class CollectorStatus(DataClassORJSONMixin):
    collector_installation_status: int = 0


@dataclass
class MnetInfo(DataClassORJSONMixin):
    model: str = ""
    revision: str = ""
    imei: str = ""


@dataclass
class DeviceData(DataClassORJSONMixin):
    sys_status: int = 0
    charge_state: int = 0
    battery_val: int = 0
    sensor_status: int = 0
    last_status: int = 0
    sys_time_stamp: str = ""
    collector_status: CollectorStatus = field(default_factory=CollectorStatus)
    mnet_info: MnetInfo = field(default_factory=MnetInfo)


@dataclass
class RTKData(DataClassORJSONMixin):
    status: int = 0
    pos_level: int = 0
    gps_stars: int = 0
    dis_status: str = ""
    co_view_stars: int = 0


@dataclass
class LocationData(DataClassORJSONMixin):
    real_pos_x: int = 0
    real_pos_y: int = 0
    real_toward: int = 0
    pos_type: int = 0
    bol_hash: str = ""


@dataclass
class Maintain(DataClassORJSONMixin):
    mileage: int = 0
    work_time: int = 0
    bat_cycles: int = 0


@dataclass
class VisionInfo(DataClassORJSONMixin):
    x: float = 0.0
    y: float = 0.0
    heading: float = 0.0
    vio_state: int = 0
    brightness: int = 1
    detect_feature_num: int = 0
    track_feature_num: int = 0


@dataclass
class WorkData(DataClassORJSONMixin):
    path: int = 0
    path_hash: str = ""
    progress: int = 0
    area: int = 0
    bp_info: int = 0
    bp_hash: str = ""
    bp_pos_x: int = 0
    bp_pos_y: int = 0
    real_path_num: str = ""
    path_pos_x: int = 0
    path_pos_y: int = 0
    ub_zone_hash: str = ""
    ub_path_hash: str = ""
    init_cfg_hash: str = ""
    ub_ecode_hash: str = ""
    nav_run_mode: int = 0
    test_mode_status: int = 0
    man_run_speed: int = 0
    nav_edit_status: int = 0
    knife_height: int = 0


@dataclass
class ReportData(DataClassORJSONMixin):
    connect: ConnectData = field(default_factory=ConnectData)
    dev: DeviceData = field(default_factory=DeviceData)
    maintenance: Maintain = field(default_factory=Maintain)
    vision_info: VisionInfo = field(default_factory=VisionInfo)
    rtk: RTKData = field(default_factory=RTKData)
    locations: list[LocationData] = field(default_factory=list)
    work: WorkData = field(default_factory=WorkData)

    def update(self, data: dict) -> None:
        locations = self.locations
        if data.get("locations") is not None:
            locations = [LocationData.from_dict(loc) for loc in data.get("locations", [])]

        self.connect = ConnectData.from_dict(data.get("connect", self.connect.to_dict()))
        self.dev = DeviceData.from_dict(data.get("dev", self.dev.to_dict()))
        self.rtk = RTKData.from_dict(data.get("rtk", self.rtk.to_dict()))
        self.maintenance = Maintain.from_dict(data.get("maintain", self.maintenance.to_dict()))
        self.vision_info = VisionInfo.from_dict(data.get("vio_to_app_info", self.vision_info.to_dict()))
        self.locations = locations
        self.work = WorkData.from_dict(data.get("work", self.work.to_dict()))



from dataclasses import dataclass
from typing import Optional

from mashumaro.mixins.orjson import DataClassORJSONMixin


@dataclass
class OpenAccount(DataClassORJSONMixin):
    displayName: str
    openId: str
    hasPassword: str
    subAccount: str
    pwdVersion: int
    mobileConflictAccount: str
    id: int
    mobileLocationCode: str
    avatarUrl: str
    domainId: int
    enableDevice: str
    status: int
    country: Optional[str] = None


@dataclass
class OauthOtherInfo(DataClassORJSONMixin):
    SidExpiredTime: int


@dataclass
class LoginSuccessResult(DataClassORJSONMixin):
    reTokenExpireIn: int
    uidToken: str
    openAccount: OpenAccount
    initPwd: str
    sidExpireIn: int
    oauthOtherInfo: OauthOtherInfo
    refreshToken: str
    sid: str
    token: str


@dataclass
class InnerDataContent(DataClassORJSONMixin):
    loginSuccessResult: LoginSuccessResult
    mobileBindRequired: str


@dataclass
class InnerData(DataClassORJSONMixin):
    traceId: str
    vid: str
    code: int
    data: InnerDataContent
    subCode: int
    message: str
    successful: str
    deviceId: Optional[str] = None


@dataclass
class LoginByOAuthResponse(DataClassORJSONMixin):
    data: InnerData
    success: str
    api: str
    errorMsg: str



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DrvKnifeChangeReport(_message.Message):
    __slots__ = ["end_high", "is_start", "start_high"]
    END_HIGH_FIELD_NUMBER: _ClassVar[int]
    IS_START_FIELD_NUMBER: _ClassVar[int]
    START_HIGH_FIELD_NUMBER: _ClassVar[int]
    end_high: int
    is_start: int
    start_high: int
    def __init__(self, is_start: _Optional[int] = ..., start_high: _Optional[int] = ..., end_high: _Optional[int] = ...) -> None: ...

class DrvKnifeHeight(_message.Message):
    __slots__ = ["knifeHeight"]
    KNIFEHEIGHT_FIELD_NUMBER: _ClassVar[int]
    knifeHeight: int
    def __init__(self, knifeHeight: _Optional[int] = ...) -> None: ...

class DrvKnifeStatus(_message.Message):
    __slots__ = ["knife_status"]
    KNIFE_STATUS_FIELD_NUMBER: _ClassVar[int]
    knife_status: int
    def __init__(self, knife_status: _Optional[int] = ...) -> None: ...

class DrvMotionCtrl(_message.Message):
    __slots__ = ["setAngularSpeed", "setLinearSpeed"]
    SETANGULARSPEED_FIELD_NUMBER: _ClassVar[int]
    SETLINEARSPEED_FIELD_NUMBER: _ClassVar[int]
    setAngularSpeed: int
    setLinearSpeed: int
    def __init__(self, setLinearSpeed: _Optional[int] = ..., setAngularSpeed: _Optional[int] = ...) -> None: ...

class DrvMowCtrlByHand(_message.Message):
    __slots__ = ["cut_knife_ctrl", "cut_knife_height", "main_ctrl", "max_run_Speed"]
    CUT_KNIFE_CTRL_FIELD_NUMBER: _ClassVar[int]
    CUT_KNIFE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    MAIN_CTRL_FIELD_NUMBER: _ClassVar[int]
    MAX_RUN_SPEED_FIELD_NUMBER: _ClassVar[int]
    cut_knife_ctrl: int
    cut_knife_height: int
    main_ctrl: int
    max_run_Speed: float
    def __init__(self, main_ctrl: _Optional[int] = ..., cut_knife_ctrl: _Optional[int] = ..., cut_knife_height: _Optional[int] = ..., max_run_Speed: _Optional[float] = ...) -> None: ...

class DrvSrSpeed(_message.Message):
    __slots__ = ["rw", "speed"]
    RW_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    rw: int
    speed: float
    def __init__(self, rw: _Optional[int] = ..., speed: _Optional[float] = ...) -> None: ...

class MctlDriver(_message.Message):
    __slots__ = ["bidire_knife_height_report", "bidire_speed_read_set", "mow_ctrl_by_hand", "rtk_cfg_req", "rtk_cfg_req_ack", "rtk_sys_mask_query", "rtk_sys_mask_query_ack", "toapp_knife_status", "toapp_knife_status_change", "todev_devmotion_ctrl", "todev_knife_height_set"]
    BIDIRE_KNIFE_HEIGHT_REPORT_FIELD_NUMBER: _ClassVar[int]
    BIDIRE_SPEED_READ_SET_FIELD_NUMBER: _ClassVar[int]
    MOW_CTRL_BY_HAND_FIELD_NUMBER: _ClassVar[int]
    RTK_CFG_REQ_ACK_FIELD_NUMBER: _ClassVar[int]
    RTK_CFG_REQ_FIELD_NUMBER: _ClassVar[int]
    RTK_SYS_MASK_QUERY_ACK_FIELD_NUMBER: _ClassVar[int]
    RTK_SYS_MASK_QUERY_FIELD_NUMBER: _ClassVar[int]
    TOAPP_KNIFE_STATUS_CHANGE_FIELD_NUMBER: _ClassVar[int]
    TOAPP_KNIFE_STATUS_FIELD_NUMBER: _ClassVar[int]
    TODEV_DEVMOTION_CTRL_FIELD_NUMBER: _ClassVar[int]
    TODEV_KNIFE_HEIGHT_SET_FIELD_NUMBER: _ClassVar[int]
    bidire_knife_height_report: DrvKnifeHeight
    bidire_speed_read_set: DrvSrSpeed
    mow_ctrl_by_hand: DrvMowCtrlByHand
    rtk_cfg_req: rtk_cfg_req_t
    rtk_cfg_req_ack: rtk_cfg_req_ack_t
    rtk_sys_mask_query: rtk_sys_mask_query_t
    rtk_sys_mask_query_ack: rtk_sys_mask_query_ack_t
    toapp_knife_status: DrvKnifeStatus
    toapp_knife_status_change: DrvKnifeChangeReport
    todev_devmotion_ctrl: DrvMotionCtrl
    todev_knife_height_set: DrvKnifeHeight
    def __init__(self, todev_devmotion_ctrl: _Optional[_Union[DrvMotionCtrl, _Mapping]] = ..., todev_knife_height_set: _Optional[_Union[DrvKnifeHeight, _Mapping]] = ..., bidire_speed_read_set: _Optional[_Union[DrvSrSpeed, _Mapping]] = ..., bidire_knife_height_report: _Optional[_Union[DrvKnifeHeight, _Mapping]] = ..., toapp_knife_status: _Optional[_Union[DrvKnifeStatus, _Mapping]] = ..., mow_ctrl_by_hand: _Optional[_Union[DrvMowCtrlByHand, _Mapping]] = ..., rtk_cfg_req: _Optional[_Union[rtk_cfg_req_t, _Mapping]] = ..., rtk_cfg_req_ack: _Optional[_Union[rtk_cfg_req_ack_t, _Mapping]] = ..., rtk_sys_mask_query: _Optional[_Union[rtk_sys_mask_query_t, _Mapping]] = ..., rtk_sys_mask_query_ack: _Optional[_Union[rtk_sys_mask_query_ack_t, _Mapping]] = ..., toapp_knife_status_change: _Optional[_Union[DrvKnifeChangeReport, _Mapping]] = ...) -> None: ...

class rtk_cfg_req_ack_t(_message.Message):
    __slots__ = ["cmd_length", "cmd_response"]
    CMD_LENGTH_FIELD_NUMBER: _ClassVar[int]
    CMD_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    cmd_length: int
    cmd_response: str
    def __init__(self, cmd_length: _Optional[int] = ..., cmd_response: _Optional[str] = ...) -> None: ...

class rtk_cfg_req_t(_message.Message):
    __slots__ = ["cmd_length", "cmd_req"]
    CMD_LENGTH_FIELD_NUMBER: _ClassVar[int]
    CMD_REQ_FIELD_NUMBER: _ClassVar[int]
    cmd_length: int
    cmd_req: str
    def __init__(self, cmd_length: _Optional[int] = ..., cmd_req: _Optional[str] = ...) -> None: ...

class rtk_sys_mask_query_ack_t(_message.Message):
    __slots__ = ["sat_system", "system_mask_bits"]
    SAT_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_MASK_BITS_FIELD_NUMBER: _ClassVar[int]
    sat_system: int
    system_mask_bits: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, sat_system: _Optional[int] = ..., system_mask_bits: _Optional[_Iterable[int]] = ...) -> None: ...

class rtk_sys_mask_query_t(_message.Message):
    __slots__ = ["sat_system"]
    SAT_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    sat_system: int
    def __init__(self, sat_system: _Optional[int] = ...) -> None: ...



from io import BytesIO

"""Notify data object"""


class BlufiNotifyData:
    """generated source for class BlufiNotifyData"""

    def __init__(self) -> None:
        self.mDataOS = BytesIO()
        self.mFrameCtrlValue = 0
        self.mPkgType = 0
        self.mSubType = 0
        self.mTypeValue = 0

    def getType(self):
        """Generated source for method getType"""
        return self.mTypeValue

    #  JADX INFO: Access modifiers changed from: package-private
    def setType(self, i) -> None:
        """Generated source for method setType"""
        self.mTypeValue = i

    #  JADX INFO: Access modifiers changed from: package-private
    def getPkgType(self):
        """Generated source for method getPkgType"""
        return self.mPkgType

    #  JADX INFO: Access modifiers changed from: package-private
    def setPkgType(self, i) -> None:
        """Generated source for method setPkgType"""
        self.mPkgType = i

    #  JADX INFO: Access modifiers changed from: package-private
    def getSubType(self):
        """Generated source for method getSubType"""
        return self.mSubType

    #  JADX INFO: Access modifiers changed from: package-private
    def setSubType(self, i) -> None:
        """Generated source for method setSubType"""
        self.mSubType = i

    def getFrameCtrl(self):
        """Generated source for method getFrameCtrl"""
        return self.mFrameCtrlValue

    #  JADX INFO: Access modifiers changed from: package-private
    def setFrameCtrl(self, i) -> None:
        """Generated source for method setFrameCtrl"""
        self.mFrameCtrlValue = i

    #  JADX INFO: Access modifiers changed from: package-private
    def addData(self, bArr, i) -> None:
        """Generated source for method addData"""
        self.mDataOS.write(bArr[i:])

    #  JADX INFO: Access modifiers changed from: package-private
    def getDataArray(self):
        """Generated source for method getDataArray"""
        return self.mDataOS.getvalue()
